@@ -17,7 +17,7 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-import pacman,re
+import re
 
 class package:
 	def short_name(self):
@@ -27,10 +27,10 @@ class package:
 	def prereq(self):
 		return ""
 	def analyze(self, pkginfo, tar):
-		ret = [[],[],[]]
+		ret = [[], [], []]
 		if hasattr(pkginfo, 'backup'):
 			for item in pkginfo.backup:
-				if re.match('^/',item) != None:
+				if re.match('^/', item) != None:
 					ret[0].append(("backups-preceding-slashes", ()))
 		return ret
 	def type(self):
