@@ -17,7 +17,7 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-import tarfile, re
+import re
 
 class package:
 	def short_name(self):
@@ -27,7 +27,7 @@ class package:
 	def prereq(self):
 		return "tar"
 	def analyze(self, pkginfo, tar):
-		ret = [[],[],[]]
+		ret = [[], [], []]
 		scroll = re.compile("var.*/scrollkeeper/$")
 		for i in tar.getnames():
 			n = scroll.search(i)
