@@ -17,7 +17,7 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-import pacman, re
+import re
 
 class package:
 	def short_name(self):
@@ -27,14 +27,14 @@ class package:
 	def prereq(self):
 		return ""
 	def analyze(self, pkginfo, tar):
-		ret = [[],[],[]]
+		ret = [[], [], []]
 		contributortag = 0
 		maintainertag = 0
 		idtag = 0
 		for i in pkginfo.pkgbuild:
-			if re.match("#\s*Contributor\s*:",i) != None:
+			if re.match("#\s*Contributor\s*:", i) != None:
 				contributortag = 1
-			if re.match("#\s*Maintainer\s*:",i) != None:
+			if re.match("#\s*Maintainer\s*:", i) != None:
 				maintainertag = 1
 
 		if contributortag != 1:
